@@ -1,10 +1,8 @@
 from dxsp.protocols.client import DexClient
+from dxsp.protocols.kwenta import DexKwenta
 
 # from .oneinch import DexOneInch
 from dxsp.protocols.uniswap import DexUniswap
 from dxsp.protocols.zerox import DexZeroX
 
-__all__ = [
-    "DexUniswap",
-    "DexZeroX",
-]
+__all__ = ["DexUniswap", "DexZeroX", "DexKwenta"]
