@@ -30,9 +30,8 @@ async def get(url, params=None, headers=None):
     try:
         async with aiohttp.ClientSession() as session:
             async with session.get(
-                url, params=None, headers=None, timeout=20
+                url, params=params, headers=headers, timeout=20
             ) as response:
-                logger.debug(response)
                 if response.status == 200:
                     if response.content_length > MAX_RESPONSE_SIZE:
                         logger.warning("Response content too large, skipping...")
@@ -41,3 +40,4 @@ async def get(url, params=None, headers=None):
 
     except Exception as error:
         logger.error("get: {}", error)
+        raise error
